@@ -2,9 +2,12 @@
 #define CONFIGURATION_H_
 
 #include <gtk/gtk.h>
+#ifdef MAEMO_CHANGES
+#include <hildon/hildon.h>
+#endif
 #include <microfeed-subscriber/microfeedsubscriber.h>
 
-void show_publishers_dialog(MicrofeedSubscriber* subscriber, GtkWindow* parent);
+void show_publishers_dialog(MicrofeedSubscriber* subscriber, GtkWindow* parent, const char* identifier);
 char* show_new_dialog(MicrofeedSubscriber* subscriber, GtkWindow* parent);
 void show_edit_dialog(MicrofeedSubscriber* subscriber, GtkWindow* parent, const char* publisher);
 void show_value_dialog(MicrofeedSubscriber* subscriber, GtkWindow* parent, const char* publisher, const char* uid, const char* text, const char* value, const char* unit, const char* type, int length);
